% This code if for the book titled: Advanced Digital Signal Processing 
% of Seismic Data by Wail A. Mousa 
% January 1, 2020.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Chapter 5 MATLAB codes %%%
%%% Figure 5.10 Filtering a seismic trace using a linear-phase FIR BPF designed via a Kaiser window%%
clear,clc,close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


load A_seismic_trace

figure,
plot(t,g,'k','LineWidth',2)
xlabel('{\it t}(s)','FontName','times','FontSize',14)
ylabel('{\it g}({\it t})','FontName','times','FontSize',14) 
grid
axis tight
set(gcf,'PaperPositionMode','auto')

G=fft(g,2*nt);
f=linspace(-0.5,0.5,length(G))/dt;
figure,plot(f,abs(fftshift(G)),'k','LineWidth',2)
xlabel('{\it f}(Hz)','FontName','Times','FontSize',14)
ylabel('|{\it G}({\it e^{jf}})|','FontName','Times','FontSize',14)
axis([0,max(f),0,max(abs(G))])
set(gcf,'PaperPositionMode','auto')

%% Designing a LPF to pass the ground-roll noise
W_cut=[20,60]*2*dt;
N=45;
win=kaiser(N+1,5);
b = fir1(N,W_cut,win);

h1=fft(b,2*nt);
h1=fftshift(h1);
figure,
plot(f,abs(h1),'k','LineWidth',2)
xlabel('{\it f}(Hz)','FontName','Times','FontSize',14)
ylabel('|{\it H}({\it e^{jf}})|','FontName','Times','FontSize',14)
axis([0,max(f),0,1.25])
set(gcf,'PaperPositionMode','auto')

%% Convolving the filter with the g[n]
g_bp=conv(g,b);
g_bp=g_bp(1:length(g_bp)-N);
figure,
plot(t,g_bp,'k','LineWidth',2)
xlabel('{\it t}(s)','FontName','times','FontSize',14)
ylabel('{\it g}({\it t})','FontName','times','FontSize',14) 
grid
axis tight
set(gcf,'PaperPositionMode','auto')

G=fft(g_bp,2*nt);
f=linspace(-0.5,0.5,length(G))/dt;
figure,plot(f,abs(fftshift(G)),'k','LineWidth',2)
xlabel('{\it f}(Hz)','FontName','Times','FontSize',14)
ylabel('|{\it G}({\it e^{jf}})|','FontName','Times','FontSize',14)
axis([0,max(f),0,max(abs(G))])
set(gcf,'PaperPositionMode','auto')

