% This code if for the book titled: Advanced Digital Signal Processing 
% of Seismic Data by Wail A. Mousa 
% January 1, 2020.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Chapter 5 MATLAB codes %%%
%%% Figures 5.8 and 5.9 Various windows and a linear-phase FIR LPF designed via various windows%%
clear,clc,close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%5.8
M=21;
n=0:M;

w_rect=rectwin(M+1);
w_hamm=hamming(M+1);
w_hann=hanning(M+1);
w_kaiser=kaiser(M+1,4);
w_blackman=blackman(M+1);

plot(n,w_rect,'ok','LineWidth',2)
hold on
plot(n,w_hamm,'-ok','LineWidth',2)
plot(n,w_hann,'--ok','LineWidth',2)
plot(n,w_kaiser,'-.ok','LineWidth',2)
plot(n,w_blackman,'-ok','LineWidth',2)
xlabel('Samples','FontName','Times','FontSize',14);
axis([0,M+1,0,1.5])
grid on
hhh=legend('Rectangular','Hamming','Hanning','Kaiser','Blackman');
set(hhh,'FontName','Times')
set(gcf,'PaperPositionMode','auto')

[Wr,omg]=freqz(w_rect,128);
[Whm,omg]=freqz(w_hamm,128);
[Whn,omg]=freqz(w_hann,128);
[Wk,omg]=freqz(w_kaiser,128);
[Wbl,omg]=freqz(w_blackman,128);

figure
plot(omg,abs(Wr)/max(abs(Wr)),'k','LineWidth',2)
hold on,
plot(omg,abs(Whm)/max(abs(Whm)),'k-.','LineWidth',2)
plot(omg,abs(Whn)/max(abs(Whn)),'k--','LineWidth',2)
plot(omg,abs(Wk)/max(abs(Wk)),'k:','LineWidth',2)
plot(omg,abs(Wbl)/max(abs(Wbl)),'k-','LineWidth',2)

xlabel('\omega(rad/s)','FontName','Times','FontSize',14)
ylabel('|{\itW}(\omega)|','FontName','Times','FontSize',14)
axis tight
hold off
grid on
hhh=legend('Rectangular','Hamming','Hanning','Kaiser','Blackman');
set(hhh,'FontName','Times')
set(gcf,'PaperPositionMode','auto')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%5.9

h1=fir1(M,0.5,w_rect);
[W1]=freqz(h1,128);
h2=fir1(M,0.5,w_hamm);
[W2]=freqz(h2,128);
h3=fir1(M,0.5,w_hann);
[W3]=freqz(h3,128);
h4=fir1(M,0.5,w_kaiser);
[W4]=freqz(h4,128);
h5=fir1(M,0.5,w_blackman);
[W5]=freqz(h5,128);


figure
hold on,
plot(omg,(abs(W1)/max(abs(W1))),'k','LineWidth',2)
plot(omg,(abs(W2)/max(abs(W2))),'k-.','LineWidth',2)
plot(omg,(abs(W3)/max(abs(W3))),'k--','LineWidth',2)
plot(omg,(abs(W4)/max(abs(W4))),'k:','LineWidth',2)
plot(omg,(abs(W5)/max(abs(W5))),'k.','LineWidth',1)%'Color',[0.5 0.5 0.5],
xlabel('{\it \omega} (rad/s)','FontName','Times','FontName','Times','FontSize',14)
ylabel('|{\it H}({\it e^{\it j\omega}})|','FontName','Times','FontName','Times','FontSize',14)
axis([0,pi,0,1.1])
hold off
grid on
hhh=legend('Rectangular','Hamming','Hanning','Kaiser','Blackman');
set(hhh,'FontName','Times')
set(gcf,'PaperPositionMode','auto')



figure
hold on,
plot(omg,unwrap(angle(W1)),'k','LineWidth',2)
plot(omg,unwrap(angle(W2)),'k-.','LineWidth',2)
plot(omg,unwrap(angle(W3)),'k--','LineWidth',2)
plot(omg,unwrap(angle(W4)),'k:','LineWidth',2)
plot(omg,unwrap(angle(W5)),'k.','LineWidth',2)
xlabel('{\it \omega} (rad/s)','FontName','Times','FontName','Times','FontSize',14)
ylabel('{\it \angle{H}}({\it e^{\it j\omega}})','FontName','Times','FontName','Times','FontSize',14)
hold off
grid on
hhh=legend('Rectangular','Hamming','Hanning','Kaiser','Blackman');
set(hhh,'FontName','Times')
set(gcf,'PaperPositionMode','auto')




